from datetime import datetime
from dataclasses import dataclass

from numpy import int16, float64
from numpy.typing import NDArray


VoltageWaveformType = NDArray[float64]
RawWaveformType = NDArray[int16]


@dataclass
class Measurement:
    """Measurement is a dataclass for storing a set of waveforms generated by a single acquisition, with a timestamp."""

    waveforms: list[VoltageWaveformType] | list[RawWaveformType]
    """Contains the acquired waveforms as a list of 1D NumPy arrays or either floats or ints"""
    timestamp: datetime | None
    """The time at which the acquisition was triggered, as a datetime.datetime object"""
